@@ -1,8 +1,6 @@
 package Reply::Plugin::AutoRefresh;
-BEGIN {
-  $Reply::Plugin::AutoRefresh::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::AutoRefresh::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::AutoRefresh::VERSION = '0.39';
 use strict;
 use warnings;
 # ABSTRACT: automatically refreshes the external code you use
@@ -52,7 +50,7 @@ Reply::Plugin::AutoRefresh - automatically refreshes the external code you use
 
 =head1 VERSION
 
-version 0.37
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -80,7 +78,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
