@@ -1,8 +1,6 @@
 package Reply::Plugin::Autocomplete::Functions;
-BEGIN {
-  $Reply::Plugin::Autocomplete::Functions::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Autocomplete::Functions::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Autocomplete::Functions::VERSION = '0.39';
 use strict;
 use warnings;
 # ABSTRACT: tab completion for function names
@@ -54,7 +52,7 @@ Reply::Plugin::Autocomplete::Functions - tab completion for function names
 
 =head1 VERSION
 
-version 0.37
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -73,7 +71,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
