@@ -1,8 +1,6 @@
 package Reply::Plugin::CollapseStack;
-BEGIN {
-  $Reply::Plugin::CollapseStack::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::CollapseStack::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::CollapseStack::VERSION = '0.39';
 use strict;
 use warnings;
 # ABSTRACT: display error stack traces only on demand
@@ -80,7 +78,7 @@ Reply::Plugin::CollapseStack - display error stack traces only on demand
 
 =head1 VERSION
 
-version 0.37
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -104,7 +102,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
