@@ -1,8 +1,6 @@
 package Reply::Plugin::FancyPrompt;
-BEGIN {
-  $Reply::Plugin::FancyPrompt::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::FancyPrompt::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::FancyPrompt::VERSION = '0.39';
 use strict;
 use warnings;
 # ABSTRACT: provides a more informative prompt
@@ -47,7 +45,7 @@ Reply::Plugin::FancyPrompt - provides a more informative prompt
 
 =head1 VERSION
 
-version 0.37
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -66,7 +64,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
