@@ -1,8 +1,6 @@
 package Reply::Plugin::Nopaste;
-BEGIN {
-  $Reply::Plugin::Nopaste::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Nopaste::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Nopaste::VERSION = '0.39';
 use strict;
 use warnings;
 # ABSTRACT: command to nopaste a transcript of the current session
@@ -102,7 +100,7 @@ Reply::Plugin::Nopaste - command to nopaste a transcript of the current session
 
 =head1 VERSION
 
-version 0.37
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -130,7 +128,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
